Contexts and Executions — Renga 0.1.0.dev20170915 documentation

Join us on GitHub

# Contexts and Executions

Manage contexts and executions on the server.

Methods available on `client.contexts`:

class `renga.models.deployer.` `ContextCollection`(client=None)

  Represent projects on the server.

  Create representation of objects on the server.

  class `Meta`

    Information about individual projects.

    `model`

      alias of `Context`

  `create`(spec=None, **kwargs)

    Create new project.

  `list`()

    Return list if the collection is iterable.

## Context objects

class `renga.models.deployer.` `Context`

  Represent a deployer context.

  Create representation of object on the server.

  `executions`

    Return the collection of context executions.

  `id`

    The identifier of the object.

  `image`

    Image used for the executions.

  `labels`

    Return the context labels.

  `lineage`

    Return the lineage of this context.

  `run`(**kwargs)

    Execute the context.

  `spec`

    Specification of the execution context.

  `vertex_id`

    Graph vertex id.

## Executions

class `renga.models.deployer.` `ExecutionCollection`(context_id, **kwargs)

  Represent projects on the server.

  Initialize the collection of context executions.

  class `Meta`

    Information about individual projects.

    `model`

      alias of `Execution`

  `list`()

    Return list if the collection is iterable.

## Execution objects

class `renga.models.deployer.` `Execution`

  Represent a context execution.

  Create representation of object on the server.

  `context`

    Return the related context.

  `context_id`

    Return the associated context id.

  `engine`

    Return the execution engine.

  `id`

    The identifier of the object.

  `logs`(**kwargs)

    Get logs from this execution.

  `ports`

    Return runtime port mapping.

  `stop`()

    Stop running execution.

  `url`

    Return a URL for accessing the running container.